@@ -1,5 +1,5 @@
 /*
- * (C) 2001 	Fatih Demir <kabalak@gtranslator.org>
+ * (C) 2001-2003 	Fatih Demir <kabalak@gtranslator.org>
  *
  * gtranslator is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -26,13 +26,14 @@
  * A gtranslator-specific ID container -- is generated out of the specs for
  *  the po-file and the message.
  *
- * General format: gtranslator_bookmark:file#version/position
+ * General format: gtranslator_bookmark:file#version/position/comment
  *
  */
 typedef struct
 {
 	gchar	*file;
 	gchar	*version;
+	gchar	*comment;
 
 	gint	 position;
 } GtrBookmark;
@@ -45,6 +46,11 @@ typedef struct
  */
 GtrBookmark *gtranslator_bookmark_new(void);
 
+/*
+ * Another stupid and small convenience function for the bookmarking...
+ */
+GtrBookmark *gtranslator_bookmark_new_with_comment(const gchar *comment);
+
 /*
  * Creates the bookmark from a given gchar-string formatted by gtranslator.
  */
@@ -66,6 +72,11 @@ gchar *gtranslator_bookmark_string_from_bookmark(GtrBookmark *bookmark);
  */
 void gtranslator_bookmark_open(GtrBookmark *bookmark);
 
+/*
+ * Change the comment of a given bookmark to the given new comment "newcomment"
+ */
+void gtranslator_bookmark_set_comment(GtrBookmark *bookmark, const gchar *newcomment);
+
 /*
  * Is the given GtrBookmark resolvable at all -- is the file present and do the
  *  other specs also match?!
@@ -87,6 +98,13 @@ gboolean gtranslator_bookmark_string_equal(GtrBookmark *bookmark, const gchar *s
  */
 void gtranslator_bookmark_add(GtrBookmark *bookmark);
 
+/*
+ * Adds the current position, po file directly to the IDs list without any
+ *  current handling being necessary... with/without comment.
+ */
+void gtranslator_bookmark_add_direct(void);
+void gtranslator_bookmark_add_direct_with_comment(const gchar *comment);
+
 /*
  * Remove the given GtrBookmark from the IDs list -- the result is
  *  passed as the return-value.
@@ -115,6 +133,11 @@ void gtranslator_bookmark_save_list(void);
  */
 GList *gtranslator_bookmark_get_list(void);
 
+/*
+ * Shows up the bookmarks' list in the GUI like in the history list of files.
+ */
+void gtranslator_bookmark_show_list(void);
+
 /*
  * Copy the given GtrBookmark safely.
  */
