@@ -20,7 +20,7 @@
 
 #include "about.h"
 #include "actions.h"
-#include "defines.include"
+#include "defines.h"
 #include "dialogs.h"
 #include "find.h"
 #include "gui.h"
@@ -40,7 +40,6 @@
 
 #include <libgnomeui/gnome-app.h>
 #include <libgnomeui/gnome-app-helper.h>
-//#include <libgnomeui/gnome-stock.h>
 
 GnomeUIInfo the_menus[] = {
 	GNOMEUIINFO_MENU_FILE_TREE(the_file_menu),
@@ -59,17 +58,25 @@ GnomeUIInfo the_file_menu[] = {
 		GNOME_APP_UI_ITEM, N_("_Compile"),
 		N_("Compile the po file"),
 		compile, NULL, NULL,
-		GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_CONVERT,
+		GNOME_APP_PIXMAP_STOCK, GTK_STOCK_CONVERT,
 		GDK_C, GDK_MOD1_MASK, NULL
 	},
 	{
 		GNOME_APP_UI_ITEM, N_("_Update"),
 		N_("Update the po file"),
 		update, NULL, NULL,
-		GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_REFRESH,
+		GNOME_APP_PIXMAP_STOCK, GTK_STOCK_REFRESH,
 		GDK_F5, 0, NULL
 	},
 	GNOMEUIINFO_SEPARATOR,
+	{
+		GNOME_APP_UI_ITEM, N_("Add bookmark"),
+		N_("Add a bookmark for this message in this po file"),
+		gtranslator_bookmark_adding_dialog, NULL, NULL,
+		GNOME_APP_PIXMAP_STOCK, GTK_STOCK_ADD,
+		GDK_F2, 0, NULL
+	},
+	GNOMEUIINFO_SEPARATOR,
 	{
 		GNOME_APP_UI_ITEM, N_("Aut_otranslate..."),
 		N_("Autotranslate the file with information from your learn buffer"),
@@ -82,7 +89,7 @@ GnomeUIInfo the_file_menu[] = {
 		GNOME_APP_UI_ITEM, N_("Remove all translations..."),
 		N_("Remove all existing translations from the po file"),
 		gtranslator_remove_all_translations_dialog, NULL, NULL,
-		GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_TRASH,
+		GNOME_APP_PIXMAP_STOCK, GTK_STOCK_DELETE,
 		0, 0, NULL
 	},
 	GNOMEUIINFO_SEPARATOR,
@@ -91,7 +98,7 @@ GnomeUIInfo the_file_menu[] = {
 		GNOME_APP_UI_ITEM, N_("Open from _URI..."),
 		N_("Open a po file from a given URI"),
 		gtranslator_open_uri_dialog, NULL, NULL,
-		GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_OPEN,
+		GNOME_APP_PIXMAP_STOCK, GTK_STOCK_OPEN,
 		GDK_F3, GDK_MOD1_MASK, NULL
 	},
 	GNOMEUIINFO_MENU_SAVE_ITEM(gtranslator_save_current_file_dialog, NULL),
@@ -101,21 +108,23 @@ GnomeUIInfo the_file_menu[] = {
 	GNOMEUIINFO_SEPARATOR,
 	GNOMEUIINFO_SUBTREE(N_("Recen_t files"), the_last_files_menus),
 	GNOMEUIINFO_SEPARATOR,
+#ifdef UTF8_CODE
 	{
 		GNOME_APP_UI_ITEM, N_("_Export to UTF-8..."),
 		N_("Export the current po file to UTF-8"),
 		gtranslator_export_dialog, NULL, NULL,
-		GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_BOOK_YELLOW,
+		GNOME_APP_PIXMAP_STOCK, GTK_STOCK_BOOK_YELLOW,
 		GDK_E, GDK_MOD1_MASK, NULL
 	},
 	{
 		GNOME_APP_UI_ITEM, N_("_Import from UTF-8..."),
 		N_("Import a UTF-8 encoded po file into it's corresponding plain encoding"),
 		gtranslator_import_dialog, NULL, NULL,
-		GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_BOOK_RED,
+		GNOME_APP_PIXMAP_STOCK, GTK_STOCK_BOOK_RED,
 		GDK_I, GDK_MOD1_MASK, NULL
 	},
 	GNOMEUIINFO_SEPARATOR,
+#endif
 	GNOMEUIINFO_MENU_EXIT_ITEM(gtranslator_quit, NULL),
 	GNOMEUIINFO_END
 };
@@ -152,7 +161,7 @@ GnomeUIInfo the_edit_menu[] = {
 		GNOME_APP_UI_ITEM, N_("_Header..."),
 		N_("Edit po file header"),
 		gtranslator_header_edit_dialog, NULL, NULL,
-		GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PROP,
+		GNOME_APP_PIXMAP_STOCK, GTK_STOCK_PROPERTIES,
 		GDK_F8, 0, NULL
 	},
 	GNOMEUIINFO_SEPARATOR,
@@ -191,14 +200,14 @@ GnomeUIInfo the_go_menu[] = {
 	 GNOME_APP_UI_ITEM, N_("_First"),
 	 N_("Go to the first message"),
 	 gtranslator_message_go_to_first, NULL, NULL,
-	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_FIRST,
+	 GNOME_APP_PIXMAP_STOCK, GTK_STOCK_GOTO_FIRST,
 	 GDK_Up, GDK_CONTROL_MASK, NULL
 	},
 	{
 	 GNOME_APP_UI_ITEM, N_("_Back"),
 	 N_("Move back one message"),
 	 gtranslator_message_go_to_previous, NULL, NULL,
-	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_BACK,
+	 GNOME_APP_PIXMAP_STOCK, GTK_STOCK_GO_BACK,
 	 GDK_Left, GDK_CONTROL_MASK, NULL
 	},
 	GNOMEUIINFO_SEPARATOR,
@@ -206,14 +215,14 @@ GnomeUIInfo the_go_menu[] = {
 	 GNOME_APP_UI_ITEM, N_("_Next"),
 	 N_("Move forward one message"),
 	 gtranslator_message_go_to_next, NULL, NULL,
-	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_FORWARD,
+	 GNOME_APP_PIXMAP_STOCK, GTK_STOCK_GO_FORWARD,
 	 GDK_Right, GDK_CONTROL_MASK, NULL
 	},
 	{
 	 GNOME_APP_UI_ITEM, N_("_Last"),
 	 N_("Go to the last message"),
 	 gtranslator_message_go_to_last, NULL, NULL,
-	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_LAST,
+	 GNOME_APP_PIXMAP_STOCK, GTK_STOCK_GOTO_LAST,
 	 GDK_Down, GDK_CONTROL_MASK, NULL
 	},
 	GNOMEUIINFO_SEPARATOR,
@@ -221,7 +230,7 @@ GnomeUIInfo the_go_menu[] = {
 	 GNOME_APP_UI_ITEM, N_("_Go to..."),
 	 N_("Goto specified message number"),
 	 gtranslator_go_to_dialog, NULL, NULL,
-	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_JUMP_TO,
+	 GNOME_APP_PIXMAP_STOCK, GTK_STOCK_JUMP_TO,
 	 'G', GDK_CONTROL_MASK, NULL
 	},
 	{
@@ -243,10 +252,15 @@ GnomeUIInfo the_go_menu[] = {
 
 
 GnomeUIInfo the_view_menu[] = {
+	GNOMEUIINFO_SUBTREE(N_("_Bookmarks"), the_bookmarks_menu),
 	GNOMEUIINFO_SUBTREE(N_("_Colorschemes"), the_colorschemes_menu),
 	GNOMEUIINFO_END
 };
 
+GnomeUIInfo the_bookmarks_menu[] = {
+	GNOMEUIINFO_END
+};
+
 GnomeUIInfo the_colorschemes_menu[] = {
 	GNOMEUIINFO_END
 };
@@ -256,7 +270,7 @@ GnomeUIInfo the_help_menu[] = {
 	GNOMEUIINFO_ITEM_STOCK(N_("gtranslator _website"),
 			       N_("gtranslator's homepage on the web"),
 			       gtranslator_utils_show_home_page,
-			       GNOME_STOCK_MENU_HOME),
+			       GTK_STOCK_HOME),
 	GNOMEUIINFO_MENU_ABOUT_ITEM(gtranslator_about_dialog, NULL),
 	GNOMEUIINFO_END
 };
@@ -268,33 +282,33 @@ GnomeUIInfo the_toolbar[] = {
 	GNOMEUIINFO_ITEM_STOCK(N_("Open"),
 			       N_("Open a po file"),
 			       gtranslator_open_file_dialog,
-			       GNOME_STOCK_PIXMAP_OPEN),
+			       GTK_STOCK_OPEN),
 	GNOMEUIINFO_ITEM_STOCK(N_("Save"),
 			       N_("Save File"),
 			       gtranslator_save_current_file_dialog,
-			       GNOME_STOCK_PIXMAP_SAVE),
+			       GTK_STOCK_SAVE),
 	GNOMEUIINFO_ITEM_STOCK(N_("Save as"),
 			       N_("Save file with a different name"),
 			       gtranslator_save_file_as_dialog,
-			       GNOME_STOCK_PIXMAP_SAVE_AS),
+			       GTK_STOCK_SAVE_AS),
 	GNOMEUIINFO_SEPARATOR,
 	GNOMEUIINFO_ITEM_STOCK(N_("Compile"),
 			       N_("Compile the po file"),
 			       compile,
-			       GNOME_STOCK_PIXMAP_CONVERT),
+			       GTK_STOCK_CONVERT),
 	GNOMEUIINFO_ITEM_STOCK(N_("Update"),
 			       N_("Update the po file"),
 			       update,
-			       GNOME_STOCK_PIXMAP_REFRESH),
+			       GTK_STOCK_REFRESH),
 	GNOMEUIINFO_ITEM_STOCK(N_("Header"),
 			       N_("Edit the header"),
 			       gtranslator_header_edit_dialog,
-			       GNOME_STOCK_PIXMAP_PROPERTIES),
+			       GTK_STOCK_PROPERTIES),
 	GNOMEUIINFO_SEPARATOR,
 	GNOMEUIINFO_ITEM_STOCK(N_("Undo"),
 			       N_("Undo the last performed action"),
 			       gtranslator_actions_undo,
-			       GNOME_STOCK_PIXMAP_UNDO),
+			       GTK_STOCK_UNDO),
 	GNOMEUIINFO_END
 };
 
@@ -302,20 +316,20 @@ GnomeUIInfo the_navibar[] = {
 	GNOMEUIINFO_ITEM_STOCK(N_("First"),
 			       N_("Go to the first message"),
 			       gtranslator_message_go_to_first,
-			       GNOME_STOCK_PIXMAP_FIRST),
+			       GTK_STOCK_GOTO_FIRST),
 	GNOMEUIINFO_ITEM_STOCK(N_("Back"),
 			       N_("Move back one message"),
 			       gtranslator_message_go_to_previous,
-			       GNOME_STOCK_PIXMAP_BACK),
+			       GTK_STOCK_GO_BACK),
 	GNOMEUIINFO_SEPARATOR,
 	GNOMEUIINFO_ITEM_STOCK(N_("Next"),
 			       N_("Move forward one message"),
 			       gtranslator_message_go_to_next,
-			       GNOME_STOCK_PIXMAP_FORWARD),
+			       GTK_STOCK_GO_FORWARD),
 	GNOMEUIINFO_ITEM_STOCK(N_("Last"),
 			       N_("Go to the last message"),
 			       gtranslator_message_go_to_last,
-			       GNOME_STOCK_PIXMAP_LAST),
+			       GTK_STOCK_GOTO_LAST),
 	{
 		GNOME_APP_UI_ITEM, N_("Missing"),
 		N_("Go to next untranslated message"),
@@ -333,15 +347,15 @@ GnomeUIInfo the_navibar[] = {
 	GNOMEUIINFO_ITEM_STOCK(N_("Go to"),
 			       N_("Go to specified message number"),
 			       gtranslator_go_to_dialog,
-			       GNOME_STOCK_PIXMAP_JUMP_TO),
+			       GTK_STOCK_JUMP_TO),
 	GNOMEUIINFO_ITEM_STOCK(N_("Find"),
 			       N_("Find string in po file"),
 			       gtranslator_find_dialog,
-			       GNOME_STOCK_PIXMAP_SEARCH),
+			       GTK_STOCK_FIND),
 	GNOMEUIINFO_ITEM_STOCK(N_("Replace"),
 			       N_("Replace string in po file"),
 			       gtranslator_replace_dialog,
-			       GNOME_STOCK_PIXMAP_SRCHRPL),
+			       GTK_STOCK_FIND_AND_REPLACE),
 	{
 		GNOME_APP_UI_ITEM, N_("Query"),
 		N_("Query for a string"),
