@@ -525,7 +525,11 @@ void gtranslator_message_change_status(GtkWidget  * item, gpointer which)
 void gtranslator_message_go_to(GList * to_go)
 {
 	static gint pos = 0;
-
+	GtrMsg *msg = NULL;
+	GtkTextBuffer *buffer = NULL;
+	GtkTextIter iter;
+	GtkTextMark *mark = NULL;
+ 
 	g_return_if_fail (to_go!=NULL);
 
 	gtranslator_message_update();
@@ -538,10 +542,30 @@ void gtranslator_message_go_to(GList * to_go)
 	{
 		gtranslator_actions_enable(ACT_NEXT, ACT_LAST);
 	}
+
+	/* Save cursor position */
+	buffer = gtk_text_view_get_buffer(trans_box);
+	if (buffer != NULL) {
+		mark = gtk_text_buffer_get_insert(buffer);
+		gtk_text_buffer_get_iter_at_mark(buffer, &iter, mark);
+
+		msg = GTR_MSG(po->current->data);
+		msg->cursor_offset = gtk_text_iter_get_offset(&iter);
+	}
 	
 	po->current = to_go;
 	gtranslator_message_show(po->current->data);
 
+	/* Restore cursor position */
+	buffer = gtk_text_view_get_buffer(trans_box);
+	if (buffer != NULL) {
+		msg = GTR_MSG(po->current->data);
+		if (msg->cursor_offset > 0) {
+			gtk_text_buffer_get_iter_at_offset(buffer, &iter, msg->cursor_offset);
+			gtk_text_buffer_place_cursor(buffer, &iter);
+		}
+	}
+
 	if(GtrPreferences.show_messages_table)
 	{
 		gtranslator_messages_table_select_row(GTR_MSG(po->current->data));
@@ -636,12 +660,10 @@ void gtranslator_message_status_set_fuzzy(GtrMsg * msg, gboolean fuzzy)
 		}
 
 		gtranslator_comment_update(&msg->comment, comchar);
+
+		/* No need to free comment. Fixes several crashes and file corruption bugs */
+		/* GTR_FREE(comment); */
 		
-		/*
-		 * FIXME: Crashes currently...
-		 * FIXED?
-		 */
-		GTR_FREE(comment);
 		GTR_FREE(comchar);
 	} else {
 		msg->status &= ~GTR_MSG_STATUS_FUZZY;
