@@ -1,5 +1,5 @@
 /*
- * (C) 2000-2001 	Fatih Demir <kabalak@gtranslator.org>
+ * (C) 2000-2003 	Fatih Demir <kabalak@gtranslator.org>
  *			Gediminas Paulauskas <menesis@gtranslator.org>
  *
  * gtranslator is free software; you can redistribute it and/or modify
@@ -70,6 +70,11 @@ typedef struct {
 	 * Is the file write-permitted?
 	 */
 	gboolean no_write_perms;
+
+	/*
+	 * Did we already create the table for the po file.
+	 */
+	gboolean table_already_created;
 	
 	/*
 	 * The translated entries. 
@@ -112,9 +117,9 @@ extern gboolean message_changed;
 /*
  * Core backend functions for parsing a po file.
  */ 
-gboolean gtranslator_parse_core(void);
-void gtranslator_po_free(void);
-void gtranslator_parse(const gchar *po);
+gboolean gtranslator_parse_core(GtrPo *po);
+void gtranslator_po_free(GtrPo *po);
+GtrPo *gtranslator_parse(const gchar *po);
 
 /*
  * Save the file with the given filename.
@@ -123,10 +128,15 @@ gboolean gtranslator_save_file(const gchar *name);
 
 /*
  * The main granslator parse function which does use the backend
- *  calls from above and also sets up the GUI.
+ *  calls from above.
  */
 void gtranslator_parse_main(const gchar *po);
 
+/*
+ * The parts that sets up the GUI after it's been parsed
+ */
+void gtranslator_parse_main_extra();
+
 /*
  * Callbacks for the widgets
  */
