@@ -1,5 +1,5 @@
 /*
- * (C) 2000-2002 	Fatih Demir <kabalak@gtranslator.org>
+ * (C) 2000-2003 	Fatih Demir <kabalak@gtranslator.org>
  *			Gediminas Paulauskas <menesis@gtranslator.org>
  * 
  * gtranslator is free software; you can redistribute it and/or modify
@@ -34,17 +34,21 @@ struct {
 	guint save_geometry		: 1;
 	guint unmark_fuzzy		: 1;
 	
-	/*
-	 * Options, used NOT in prefs-box.
-	 */
 	guint match_case		: 1;
-	guint find_in			: 3;
+	guint fi_comments		: 1;
+	guint fi_english		: 1;
+	guint fi_translation		: 1;
+	guint ignore_hotkeys		: 1;
+	guint ri_comments		: 1;
+	guint ri_english		: 1;
+	guint ri_translation		: 1;
 	guint use_learn_buffer		: 1;
 	guint fuzzy_matching		: 1;
 	guint auto_learn		: 1;
 	guint show_messages_table	: 1;
 	guint show_comment		: 1;
-	guint collapse_translated	: 1;
+	guint collapse_all		: 1;
+	guint show_plural_forms		: 1;
 
 	/*
 	 * Special options, taken by value in the prefs-box.
@@ -66,6 +70,8 @@ struct {
 	guint autosave_with_suffix	: 1;
 	guint max_history_entries	: 10;
 
+	guint hotkey_char;
+
 	/*
 	 * The autosave timeout in minutes.
 	 */
