@@ -25,23 +25,18 @@
 /*
  * Return TRUE/FALSE if the current file is a UTF-8 file.
  */
-gboolean gtranslator_utf8_po_file_is_utf8(void);
+gboolean gtranslator_utf8_po_file_is_utf8(GtrPo *po);
 
 /*
  * Convert the msgid & msgstr's to/from UTF-8.
  */
-void gtranslator_utf8_convert_message_to_utf8(GtrMsg *msg);
-void gtranslator_utf8_convert_message_from_utf8(GtrMsg *msg);
+void gtranslator_utf8_convert_message_to_utf8(GtrMsg *msg, const gchar *orig_enc);
+void gtranslator_utf8_convert_message_from_utf8(GtrMsg *msg, const gchar *orig_enc);
 
 /*
  * Convert the whole messages to/from UTF-8.
  */
-void gtranslator_utf8_convert_po_to_utf8(void);
-void gtranslator_utf8_convert_po_from_utf8(void);
-
-/*
- * Simple typing castration is shown in here...
- */
-gchar *gtranslator_utf8_convert_to_utf8(const gchar *str);
+void gtranslator_utf8_convert_po_to_utf8(GtrPo *po);
+void gtranslator_utf8_convert_po_from_utf8(GtrPo *po);
 
 #endif
